@@ -1,30 +1,33 @@
 """
 TODO: write doc
 """
-__title__ = 'Time'
+__title__ = "Time"
 
 import datetime
+from typing import cast
+
 import astropy.time
 import astropy.units as u
 import pytz
 from astroplan import Observer
 
 
-class Time(astropy.time.Time):
+class Time(astropy.time.Time):  # type: ignore
     """Hashable Time class."""
+
     _now_offset = astropy.time.TimeDelta(0 * u.second)
 
-    def __hash__(self):
+    def __hash__(self) -> int:
         if self.ndim != 0:
             raise TypeError("unhashable type: '{}'".format(self.__class__.__name__))
         return hash((self.jd1, self.jd2, self.scale))
 
     @classmethod
-    def set_offset_to_now(cls, delta: astropy.time.TimeDelta):
+    def set_offset_to_now(cls, delta: astropy.time.TimeDelta) -> None:
         cls._now_offset = delta
 
     @classmethod
-    def now(cls):
+    def now(cls) -> "Time":
         """
         Creates a new object corresponding to the instant in time this
         method is called.
@@ -41,7 +44,7 @@ class Time(astropy.time.Time):
         """
         # call `utcnow` immediately to be sure it's ASAP
         dtnow = datetime.datetime.utcnow()
-        return cls(val=dtnow, format='datetime', scale='utc') + cls._now_offset
+        return cast(Time, Time(val=dtnow, format="datetime", scale="utc") + Time._now_offset)
 
     def night_obs(self, observer: Observer) -> datetime.date:
         """Returns the night for this time, i.e. the date of the start of the current night.
@@ -66,4 +69,4 @@ class Time(astropy.time.Time):
         return loc_dt.date()
 
 
-__all__ = ['Time']
+__all__ = ["Time"]
